/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "resources.h"
#include "kdevmonconfig.h"

#include <kapp.h>
#include <kglobal.h>
#include <kstddirs.h>
#include <kdebug.h>

KdevmonConfig *KdevmonConfig::m_config = 0L;

KdevmonConfig *KdevmonConfig::getConfig()
{
    if( m_config == 0L )
        m_config = new KdevmonConfig();
    return m_config;
}

KdevmonConfig::KdevmonConfig() {	
	commonConfig = new CommonConfig();
	graphConfig = new GraphConfig();
	mainFrameConfig = new MainFrameConfig();
	dockFrameConfig = new DockFrameConfig();
// 	popupFrameConfig = new PopupFrameConfig();
	statsFrameConfig = new StatsFrameConfig();
	
	commonConfig->configFile = QString::null;
	m_bIsInitialized = false;
}

void KdevmonConfig::readSettings()
{
    if( commonConfig->configFile == QString::null )
        commonConfig->configFile = readNameOfConfigFile();
    KConfig config( commonConfig->configFile );

	config.setGroup( "General" );
	commonConfig->colorIn =
		config.readColorEntry( "colorIn", new QColor(Qt::red) );
	commonConfig->colorOut =
		config.readColorEntry( "colorOut", new QColor(Qt::white) );
	commonConfig->refreshTime =
		config.readNumEntry( "refreshTime", 1000 );
	commonConfig->unit = (Common::Unit)
		config.readNumEntry( "unit", Common::UNIT_BYTE );
	commonConfig->smoothFactor =
		config.readNumEntry( "smoothFactor", 8 );
	
	config.setGroup( "Diagram" );
	graphConfig->showGrid =
		config.readBoolEntry( "showGrid", true );
	graphConfig->scalingMode = (Common::ScalingMode)
		config.readNumEntry( "scalingMode", Common::MODE_NORMAL );
	graphConfig->graphPosition = (Common::GraphPosition)
	    config.readNumEntry( "graphPosition", Common::POS_TOP_BOTTOM );
	graphConfig->graphStyle = (Common::GraphStyle)
	    config.readNumEntry( "graphStyle", Common::STYLE_SHADED );
	graphConfig->scaling =
	    config.readNumEntry( "scaling", 56000 );
	graphConfig->device =
	    config.readEntry( "device", "eth0" );
	
	config.setGroup( "MainFrame" );
	mainFrameConfig->bgColor =
		config.readColorEntry( "bgColor", new QColor(Qt::black) );
	mainFrameConfig->gridColor =
		config.readColorEntry( "gridColor", new QColor(Qt::gray) );
	mainFrameConfig->transparent =
		config.readBoolEntry( "transparent", false );
	mainFrameConfig->showTooltips =
	    config.readBoolEntry( "showTooltips", true );
	mainFrameConfig->showStatsBar =
	    config.readBoolEntry( "showStatsBar", true );
	mainFrameConfig->showDecorations =
		config.readBoolEntry( "showDecorations", true );
	mainFrameConfig->geometry =
		config.readRectEntry( "geometry", new QRect(0, 0, 300, 100) );
	mainFrameConfig->isVisible =
	    config.readBoolEntry( "isVisible", true );
	
	config.setGroup( "DockFrame" );
	dockFrameConfig->bgColor =
		config.readColorEntry( "bgColor", new QColor(Qt::black) );
	dockFrameConfig->isVisible =
	    config.readBoolEntry( "isVisible", true );
	dockFrameConfig->showText =
	    config.readBoolEntry( "showText", false );
	
//	config.setGroup( "PopupFrame" );
//	popupFrameConfig->position =
//		config.readPointEntry( "position", new QPoint(100, 100) );
//	popupFrameConfig->bgColor =
//	    config.readColorEntry( "bgColor", new QColor(Qt::black) );
//	popupFrameConfig->fgColor =
//	    config.readColorEntry( "fgColor", new QColor(Qt::lightGray) );
//
	config.setGroup( "StatsFrame" );
	statsFrameConfig->position =
		config.readPointEntry( "position", new QPoint(100,100) );
	statsFrameConfig->bgColor =
		config.readColorEntry( "bgColor", new QColor(Qt::black) );
	
    m_bIsInitialized = true;
}

void KdevmonConfig::writeSettings()
{
    if( commonConfig->configFile == QString::null )
        commonConfig->configFile = readNameOfConfigFile();
    KConfig config( commonConfig->configFile );
	
	config.setGroup( "General" );
	config.writeEntry( "colorIn", commonConfig->colorIn );
	config.writeEntry( "colorOut", commonConfig->colorOut );
	config.writeEntry( "refreshTime", commonConfig->refreshTime );
	config.writeEntry( "unit", (int) commonConfig->unit );
	config.writeEntry( "smoothFactor", commonConfig->smoothFactor );
		
	config.setGroup( "Diagram" );
	config.writeEntry( "showGrid", graphConfig->showGrid );
	config.writeEntry( "scalingMode", (int) graphConfig->scalingMode );
	config.writeEntry( "graphPosition", (int) graphConfig->graphPosition );
	config.writeEntry( "graphStyle", (int) graphConfig->graphStyle );
	config.writeEntry( "scaling", graphConfig->scaling );
	config.writeEntry( "device", graphConfig->device );
	
	config.setGroup( "MainFrame" );
	config.writeEntry( "bgColor", mainFrameConfig->bgColor );
	config.writeEntry( "gridColor", mainFrameConfig->gridColor );
	config.writeEntry( "showTooltips", mainFrameConfig->showTooltips );
	config.writeEntry( "showStatsBar", mainFrameConfig->showStatsBar );
	config.writeEntry( "showDecorations", mainFrameConfig->showDecorations );
	config.writeEntry( "transparent", mainFrameConfig->transparent );
	config.writeEntry( "geometry", mainFrameConfig->geometry );
	config.writeEntry( "isVisible", mainFrameConfig->isVisible );
	
	config.setGroup( "DockFrame" );
	config.writeEntry( "bgColor", dockFrameConfig->bgColor );
	config.writeEntry( "isVisible", dockFrameConfig->isVisible );
	config.writeEntry( "showText", dockFrameConfig->showText );
	
//	config.setGroup( "PopupFrame" );
//	config.writeEntry( "position", popupFrameConfig->position );
//	config.writeEntry( "bgColor", popupFrameConfig->bgColor );
//	config.writeEntry( "fgColor", popupFrameConfig->fgColor );
//
	config.setGroup( "StatsFrame" );
	config.writeEntry( "position", statsFrameConfig->position );
	config.writeEntry( "bgColor", statsFrameConfig->bgColor );
	
	config.sync();

	writeNameOfConfigFile( commonConfig->configFile );
}

struct CommonConfig *KdevmonConfig::getCommonConfig()
{
	if( ! m_bIsInitialized )
	    readSettings();
	return commonConfig;
}

struct GraphConfig *KdevmonConfig::getGraphConfig()
{
	if( ! m_bIsInitialized )
	    readSettings();
	return graphConfig;
}

struct MainFrameConfig *KdevmonConfig::getMainFrameConfig()
{
	if( ! m_bIsInitialized )
	    readSettings();
	return mainFrameConfig;
}

struct DockFrameConfig *KdevmonConfig::getDockFrameConfig()
{
	if( ! m_bIsInitialized )
	    readSettings();
	return dockFrameConfig;
}

//struct PopupFrameConfig *KdevmonConfig::getPopupFrameConfig()
//{
//	if( ! m_bIsInitialized )
//	    readSettings();
//	return popupFrameConfig;
//}
//
struct StatsFrameConfig *KdevmonConfig::getStatsFrameConfig()
{
	if( ! m_bIsInitialized )
		readSettings();
	return statsFrameConfig;
}
	
QString KdevmonConfig::readNameOfConfigFile()
{
	QString defaultConfigFile = KGlobal::dirs()->localkdedir()
	    + "share/apps/kdevmon/defaultrc";
	KConfig *dummyConfig = KApplication::kApplication()->config();
	dummyConfig->setGroup( "Common" );
    return dummyConfig->readEntry( "configFile", defaultConfigFile );
}

void KdevmonConfig::writeNameOfConfigFile( const QString& configFile )
{
	KConfig *dummyConfig = KApplication::kApplication()->config();
	dummyConfig->setGroup( "Common" );
    dummyConfig->writeEntry( "configFile", configFile );
    dummyConfig->sync();
}

