/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <iostream>

#include <qcstring.h>

#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>
#include <kdebug.h>
#include <kstddirs.h>
#include <kglobal.h>
#include <kapp.h>

#include "kdevmon.h"
#include "kdevmonconfig.h"

static const char *appName = "kdevmon";
static const char *programName = I18N_NOOP("kdevmon");
static const char *version = "v0.4.6";
static const char *description = I18N_NOOP("Network device monitor");
static int licenseType = KAboutData::License_GPL;
static const char *copyRightStatement = "(C) 2001 Henning Burchardt";
static const char *authorName = "Henning Burchardt";
static const char *authorEmailAddress = "h_burchardt@gmx.net";
	
	
static KCmdLineOptions options[] =
{
  { "config <configFile>", I18N_NOOP("The name of the config file (full path or file name)"), 0 },
  {0, 0, 0}
};

int main(int argc, char *argv[])
{

    KAboutData aboutData( appName, programName,
        version, description, licenseType,
        copyRightStatement );
    aboutData.addAuthor( authorName, 0, authorEmailAddress );
    KCmdLineArgs::init( argc, argv, &aboutData );
    KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.

    KApplication a;

    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
    QCString configFile = args->getOption( "config" );
    KdevmonConfig *config = KdevmonConfig::getConfig();
    if( ! configFile.isNull() )
    {
        if( configFile[0] != '/' )
        {
            configFile = QCString(KGlobal::dirs()->localkdedir()) +
                QCString("/share/apps/kdevmon/") + configFile;
        }
        config->getCommonConfig()->configFile = configFile;
        config->readSettings();
    }

    Kdevmon *kdevmon = new Kdevmon();
    a.setMainWidget(kdevmon);
    if( (config->getMainFrameConfig()->isVisible) ||
        (! config->getDockFrameConfig()->isVisible) )
        kdevmon->setMainFrameVisible( true );
    else
        ; // cerr << "Kdevmon is hidden.\n";

    return a.exec();
}
